@@ -289,14 +289,14 @@ class Model {
   }
 
   toJSON() {
-    return this.attrs;
+    return { ...this.attrs };
   }
 
   /**
     Returns a hash of this model's associations.
 
     ```js
-    let server = new Server({
+    let server = createServer({
       models: {
         user: Model,
         post: Model.extend({
