@@ -17,9 +17,9 @@ import uniqBy from "lodash.uniqby";
   The application serializer will apply to every response. To make specific customizations, define per-model serializers.
 
   ```js
-  import { Server, RestSerializer } from 'miragejs';
+  import { createServer, RestSerializer } from 'miragejs';
 
-  new Server({
+  createServer({
     serializers: {
       application: RestSerializer,
       user: RestSerializer.extend({
@@ -36,9 +36,9 @@ import uniqBy from "lodash.uniqby";
   - **JSONAPISerializer**, to simulate JSON:API compliant API servers:
 
     ```js
-    import { Server, JSONAPISerializer } from 'miragejs';
+    import { createServer, JSONAPISerializer } from 'miragejs';
 
-    new Server({
+    createServer({
       serializers: {
         application: JSONAPISerializer
       }
@@ -48,9 +48,9 @@ import uniqBy from "lodash.uniqby";
   - **ActiveModelSerializer**, to mock Rails APIs that use AMS-style responses:
 
     ```js
-    import { Server, ActiveModelSerializer } from 'miragejs';
+    import { createServer, ActiveModelSerializer } from 'miragejs';
 
-    new Server({
+    createServer({
       serializers: {
         application: ActiveModelSerializer
       }
@@ -60,9 +60,9 @@ import uniqBy from "lodash.uniqby";
   - **RestSerializer**, a good starting point for many generic REST APIs:
 
     ```js
-    import { Server, RestSerializer } from 'miragejs';
+    import { createServer, RestSerializer } from 'miragejs';
 
-    new Server({
+    createServer({
       serializers: {
         application: RestSerializer
       }
@@ -72,9 +72,9 @@ import uniqBy from "lodash.uniqby";
   Additionally, Mirage has a basic Serializer class which you can customize using the hooks documented below:
 
   ```js
-  import { Server, Serializer } from 'miragejs';
+  import { createServer, Serializer } from 'miragejs';
 
-  new Server({
+  createServer({
     serializers: {
       application: Serializer
     }
@@ -84,11 +84,11 @@ import uniqBy from "lodash.uniqby";
   When writing model-specific serializers, remember to extend from your application serializer so shared logic is used by your model-specific classes:
 
   ```js
-  import { Server, Serializer } from 'miragejs';
+  import { createServer, Serializer } from 'miragejs';
 
   const ApplicationSerializer = Serializer.extend()
 
-  new Server({
+  createServer({
     serializers: {
       application: ApplicationSerializer,
       blogPost: ApplicationSerializer.extend({
@@ -150,7 +150,7 @@ class Serializer {
       For example, if you had an `author` with many `blog-post`s and you wanted to sideload these, specify so in the `include` key:
 
       ```js
-      new Server({
+      createServer({
         models: {
           author: Model.extend({
             blogPosts: hasMany()
