@@ -290,7 +290,7 @@ export default class Server {
       For example,
 
       ```js
-      new Server({
+      createServer({
         routes() {
           this.namespace = '/api';
 
@@ -303,7 +303,7 @@ export default class Server {
       Note that only routes defined after `this.namespace` are affected. This is useful if you have a few one-off routes that you don't want under your namespace:
 
       ```js
-      new Server({
+      createServer({
         routes() {
 
           // this route handles /auth
@@ -332,7 +332,7 @@ export default class Server {
       For example, whenever you define a model
 
       ```js
-      new Server({
+      createServer({
         models: {
           post: Model
         }
@@ -346,7 +346,7 @@ export default class Server {
       Mirage has a default inflector, so if you write
 
       ```js
-      new Server()
+      createServer()
       ```
 
       you'll be using the node [inflected](https://github.com/martinandert/inflected#readme) package. This can be customized if you have irregular words or need to change the defaults. You can wead more in [the guide on customizing inflections](/docs/advanced/customizing-inflections).
@@ -356,7 +356,7 @@ export default class Server {
       You can also override the inflector completely and provide your own `pluralize` and `singularize` methods:
 
       ```js
-      new Server({
+      createServer({
         inflector: {
           pluralize(word) {
             // your logic
@@ -377,7 +377,7 @@ export default class Server {
       Useful if your app makes API requests to a different port.
 
       ```js
-      new Server({
+      createServer({
         routes() {
           this.urlPrefix = 'http://localhost:8080'
         }
@@ -392,7 +392,7 @@ export default class Server {
       By default there's a 400ms delay during development, and 0 delay in testing (so your tests run fast).
 
       ```js
-      new Server({
+      createServer({
         routes() {
           this.timing = 400; // default
         }
@@ -429,7 +429,7 @@ export default class Server {
       To override,
 
       ```js
-      new Server({
+      createServer({
         routes() {
           this.pretender.handledRequest = function(verb, path, request) {
             let { responseText } = request;
@@ -489,7 +489,7 @@ export default class Server {
       Mirage uses [pretender.js](https://github.com/trek/pretender) as its xhttp interceptor. In your Mirage config, `this.pretender` refers to the actual Pretender instance, so any config options that work there will work here as well.
 
       ```js
-      new Server({
+      createServer({
         routes() {
           this.pretender.handledRequest = (verb, path, request) => {
             console.log(`Your server responded to ${path}`);
@@ -695,7 +695,7 @@ export default class Server {
     or in development, you may want to load a few reference fixture files, and use factories to define the rest of your data:
 
     ```js
-    new Server({
+    createServer({
       ...,
       seeds(server) {
         server.loadFixtures('countries', 'states');
@@ -935,7 +935,7 @@ export default class Server {
     And one from setting up your development database:
 
     ```js
-    new Server({
+    createServer({
       seeds(server) {
         let contact = server.create('contact')
 
